import { Injectable } from '@nestjs/common';
import { JwtService } from '@nestjs/jwt';
import * as bcrypt from 'bcryptjs';
import { UserService } from '../user/user.service';
import {JwtPayload} from './dto/JwtPayload.interface'

@Injectable()
export class AuthService {
  constructor(
    private userService: UserService,
    private jwtService: JwtService,
  ) {}

  async validateUser(email: string, password: string): Promise<any> {
    const user = await this.userService.findUserAndRoleByEmail(email);

    if (user && bcrypt.compareSync(password, user.password)) {
      return user; 
    }
    return null;
  }

  async login(user: any) {
    const payload = { 
      sub: user.id,
      roles: user.roles,
    };
    
    const token = this.jwtService.sign(payload);
    return { access_token: token };
  }
}
