import {
    CanActivate,
    ExecutionContext,
    Injectable,
    UnauthorizedException,
  } from '@nestjs/common';
  import { JwtService } from '@nestjs/jwt';
  import { Request } from 'express';
  import { Reflector } from '@nestjs/core';
  import { IS_PUBLIC_KEY } from './public.decorator';
  
  @Injectable()
  export class RolesGuard implements CanActivate {
    constructor(
      private jwtService: JwtService,
      private reflector: Reflector,
    ) {}
  
    async canActivate(context: ExecutionContext): Promise<boolean> {
      const isPublic = this.reflector.getAllAndOverride<boolean>(IS_PUBLIC_KEY, [
        context.getHandler(),
        context.getClass(),
      ]);

      if (isPublic) {
        return true;
      }
  
      const request = context.switchToHttp().getRequest();
      const token = this.extractTokenFromHeader(request);
  
      const roles = this.reflector.getAllAndOverride<string[]>('roles', [
        context.getHandler(),
        context.getClass(),
      ]);

      if (!token || roles?.length === 0) {
        console.log('erro tamanho da role')
        throw new UnauthorizedException();
      }
  
      let payload;
      try {
        payload = await this.jwtService.verifyAsync(token, {
          secret: "secretKey"
        });
        request['user'] = payload;
      } catch {
        console.log('erro no parse')
        throw new UnauthorizedException();
      }
  
      const userRoles = payload.roles;
      if (!userRoles || !userRoles.some(role => roles.includes(role))) {
        console.log('erro aqui ao ver roles')
        throw new UnauthorizedException();
      }
  
      return true;
    }
  
    private extractTokenFromHeader(request: Request): string | undefined {
      const [type, token] = request.headers.authorization?.split(' ') ?? [];
      return type === 'Bearer' ? token : undefined;
    }
  }