import { ApiProperty } from '@nestjs/swagger';
import { IsNotEmpty, IsString, IsOptional, IsBoolean, IsIn } from 'class-validator';

export class CreateTaskDto {
    @ApiProperty({
        example: 'Implementar autenticação',
        description: 'Título da tarefa',
    })
    @IsNotEmpty()
    @IsString()
    title: string;

    @ApiProperty({
        example: 'Criar sistema de login com JWT',
        description: 'Descrição detalhada da tarefa',
        required: false,
    })
    @IsOptional()
    @IsString()
    description?: string;

    @ApiProperty({
        example: false,
        description: 'Status de conclusão da tarefa',
        default: false,
        required: false,
    })
    @IsOptional()
    @IsBoolean()
    completed?: boolean;

    @ApiProperty({
        example: 'high',
        description: 'Prioridade da tarefa: low, medium ou high',
        default: 'medium',
        enum: ['low', 'medium', 'high'],
        required: false,
    })
    @IsOptional()
    @IsIn(['low', 'medium', 'high'])
    priority?: string;
}