import { Controller, Get, Post, Body, Patch, Param, Delete, ParseIntPipe } from '@nestjs/common';
import { TasksService } from './tasks.service';
import { CreateTaskDto } from './dto/create-task.dto';
import { UpdateTaskDto } from './dto/update-task.dto';
import { ApiTags, ApiOperation, ApiResponse, ApiParam } from '@nestjs/swagger';

@ApiTags('tasks')
@Controller('tasks')
export class TasksController {
    constructor(private readonly tasksService: TasksService) {}

    @Post()
    @ApiOperation({ summary: 'Criar uma nova tarefa' })
    @ApiResponse({ status: 201, description: 'Tarefa criada com sucesso' })
    @ApiResponse({ status: 400, description: 'Dados inválidos' })
    create(@Body() createTaskDto: CreateTaskDto) {
        return this.tasksService.create(createTaskDto);
    }

    @Get()
    @ApiOperation({ summary: 'Listar todas as tarefas' })
    @ApiResponse({
        status: 200,
        description: 'Lista de tarefas retornada com sucesso',
    })
    findAll() {
        return this.tasksService.findAll();
    }

    @Get(':id')
    @ApiOperation({ summary: 'Obter uma tarefa pelo ID' })
    @ApiParam({ name: 'id', description: 'ID da tarefa' })
    @ApiResponse({ status: 200, description: 'Tarefa encontrada com sucesso' })
    @ApiResponse({ status: 404, description: 'Tarefa não encontrada' })
    findOne(@Param('id', ParseIntPipe) id: number) {
        return this.tasksService.findOne(id);
    }

    @Patch(':id')
    @ApiOperation({ summary: 'Atualizar uma tarefa pelo ID' })
    @ApiParam({ name: 'id', description: 'ID da tarefa' })
    @ApiResponse({ status: 200, description: 'Tarefa atualizada com sucesso' })
    @ApiResponse({ status: 404, description: 'Tarefa não encontrada' })
    update(@Param('id', ParseIntPipe) id: number, @Body() updateTaskDto: UpdateTaskDto) {
        return this.tasksService.update(id, updateTaskDto);
    }

    @Delete(':id')
    @ApiOperation({ summary: 'Remover uma tarefa pelo ID' })
    @ApiParam({ name: 'id', description: 'ID da tarefa' })
    @ApiResponse({ status: 200, description: 'Tarefa removida com sucesso' })
    @ApiResponse({ status: 404, description: 'Tarefa não encontrada' })
    remove(@Param('id', ParseIntPipe) id: number) {
        return this.tasksService.remove(id);
    }

    @Patch(':id/complete')
    @ApiOperation({ summary: 'Marcar uma tarefa como concluída' })
    @ApiParam({ name: 'id', description: 'ID da tarefa' })
    @ApiResponse({ status: 200, description: 'Tarefa marcada como concluída com sucesso' })
    @ApiResponse({ status: 404, description: 'Tarefa não encontrada' })
    markAsCompleted(@Param('id', ParseIntPipe) id: number) {
        return this.tasksService.markAsCompleted(id);
    }
}
