import { Injectable, NotFoundException } from '@nestjs/common';
import { PrismaService } from '../prisma/prisma.service';
import { CreateTaskDto } from './dto/create-task.dto';
import { UpdateTaskDto } from './dto/update-task.dto';

@Injectable()
export class TasksService {
    constructor(private prisma: PrismaService) {}

    async create(createTaskDto: CreateTaskDto) {
        return this.prisma.task.create({
            data: createTaskDto,
        });
    }

    async findAll() {
        return this.prisma.task.findMany({
            orderBy: {
                createdAt: 'desc',
            },
        });
    }

    async findOne(id: number) {
        const task = await this.prisma.task.findUnique({
            where: { id },
        });

        if (!task) {
            throw new NotFoundException(`Tarefa com ID ${id} não encontrada`);
        }

        return task;
    }

    async update(id: number, updateTaskDto: UpdateTaskDto) {
        try {
            return await this.prisma.task.update({
                where: { id },
                data: updateTaskDto,
            });
        } catch (error) {
            throw new NotFoundException(`Tarefa com ID ${id} não encontrada`);
        }
    }

    async remove(id: number) {
        try {
            return await this.prisma.task.delete({
                where: { id },
            });
        } catch (error) {
            throw new NotFoundException(`Tarefa com ID ${id} não encontrada`);
        }
    }

    async markAsCompleted(id: number) {
        try {
            return await this.prisma.task.update({
                where: { id },
                data: { completed: true },
            });
        } catch (error) {
            throw new NotFoundException(`Tarefa com ID ${id} não encontrada`);
        }
    }
}
