import { Controller, Post, Body, Get, Param, UseGuards } from '@nestjs/common';
import { UserService } from './user.service';
import { ApiBody } from '@nestjs/swagger';
import { CreateUserDto } from './dto/CreateUserDto ';
import { Roles } from 'src/auth/roles.decorator';
import { RolesGuard } from 'src/auth/role.guard';

@Controller('users')
export class UserController {
  constructor(private readonly userService: UserService) {}

  // Criar um novo usuário
  @Post()
  @ApiBody({ type: CreateUserDto })  
  async createUser(@Body() body: CreateUserDto) {
    return this.userService.createUser(body);
  }

  // Buscar um usuário por email
  @Get('document/:document')
  async findUserBydocument(@Param('document') document: string) {
    return this.userService.findOneByDocument(document);
  }

  // Buscar um usuário por ID
  @Roles('user')
  @UseGuards(RolesGuard)
  @Get(':id')
  async findUserById(@Param('id') id: string) {
    const parsedId = parseInt(id, 10);
    return this.userService.findOneById(parsedId);
  }
}