#!/bin/bash
set -e

echo "=== Iniciando ambiente de desenvolvimento do backend ==="

# Verificar se o Docker está rodando
if ! docker info > /dev/null 2>&1; then
  echo "Docker não está rodando. Por favor, inicie o Docker e tente novamente."
  exit 1
fi

# Criar rede local se não existir
if ! docker network ls | grep -q local; then
  echo "Criando rede Docker 'local'..."
  docker network create local
fi

# Verificar se o banco de dados está rodando
if ! docker ps | grep -q pg_container; then
  echo "Iniciando o banco de dados PostgreSQL..."
  docker-compose up -d
else
  echo "Banco de dados já está rodando."
fi

if [ ! -d "node_modules" ]; then
  echo "Instalando dependências do backend..."
  npm install
fi

echo "Gerando Prisma Client..."
npm run prisma:generate

read -p "Deseja executar migrações do banco de dados? (s/n): " run_migrations
if [[ $run_migrations == "s" || $run_migrations == "S" ]]; then
  echo "Executando migrações do banco de dados..."
  npm run prisma:migrate
fi

echo "Iniciando o servidor NestJS..."
npm run start:dev